These are the tool containers for the Atropos paper.

* adapter-removal: [AdapterRemoval2](https://github.com/MikkelSchubert/adapterremoval) v2.2.2, 
* art: A [modified](https://sourceforge.net/projects/skewer/files/Simulator/) version of the [Art](https://www.niehs.nih.gov/research/resources/software/biostatistics/art/) simulator v1.5.1 that adds adapters to simulated reads.
* atropos-paper-analysis: Contains tools to support the analyisis scripts; [BedOps](https://bedops.readthedocs.io/en/latest/) v2.4.26 and [SRA tools](https://github.com/ncbi/sra-tools) v2.8.2.
* atropos-paper: The version of Atropos used in the paper.
* bwa: [BWA](https://github.com/lh3/bwa) v0.7.7, [bwa-meth](https://github.com/brentp/bwa-meth) v0.1.c0 and [samtools](http://www.htslib.org/) v1.7.
* python-bash: Python 3.6 and many libraries for analysis and visualization (pandas, matplotlib, seaborn).
* seqpurge: [ngs-bits](https://github.com/imgag/ngs-bits) v0.1, which contains SeqPurge.
* skewer: [Skewer](https://github.com/relipmoc/skewer) v0.2.2.
* star: [STAR](https://github.com/alexdobin/STAR) v2.5.4b.
* fastp: [fastp](https://github.com/OpenGene/fastp) v0.12.3
* cutadapt: [Cutadapt](https://github.com/marcelm/cutadapt) v1.16